==> cuyo_1.04.orig.tar.gz: cuyo-1.04/src/prefs.h <==
/***************************************************************************
                          prefs.h  -  description
                             -------------------
    begin                : Wed Jul 12 2000
    copyright            : (C) 2000 by Immi
    email                : cuyo@pcpool.mathematik.uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef PREFS_H
#define PREFS_H

#include "inkompatibel.h"

#include <qwidget.h>
#include <qgroupbox.h>
#include <qpushbutton.h>
#include <qcheckbox.h>
#include <qlabel.h>
#include <qdialog.h>
#include "tastenbtn.h"

#define anz_spieler_in_dlg 2

/* Konstanten fr das Tasten-Array */
#define taste_links 0
#define taste_rechts 1
#define taste_dreh 2
#define taste_fall 3

/** Der Preferences-Dialog
  *@author Immi
  */

class Prefs : public QDialog  {
   Q_OBJECT
  /* Faules Programmieren... (keine get-/set-Methoden ntig)... Nennen wir es
  	 extreme programming ;-) */
	friend class Cuyo;
public:
	Prefs(QWidget *parent=0, const char *name=0);
	~Prefs();

protected: 
	void initDialog();
  /** Erzeugt einen von diesen Buttons, in denen
eine Taste eingegeben wird */
  TastenBtn * erzeugTastenBtn(const char * na, int x, int y, bool text_unten);
	
	QPushButton *mOK;
	QPushButton *mAbbrechen;
	TastenBtn *mTasten[anz_spieler_in_dlg][4];
	//QCheckBox *mTaste1Spieler;

private: 
};

#endif

==> cuyo_1.8.5.orig.tar.gz: cuyo-1.8.5/src/prefs.h <==

/***************************************************************************
                          prefs.h  -  description
                             -------------------
    begin                : Wed Jul 12 2000
    copyright            : (C) 2000 by Immi
    email                : cuyo@pcpool.mathematik.uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef PREFS_H
#define PREFS_H

#include "inkompatibel.h"

#include <qwidget.h>
#include <qgroupbox.h>
#include <qpushbutton.h>
#include <qcheckbox.h>
#include <qlabel.h>
#include <qdialog.h>
#include <qscrollbar.h>
#include "tastenbtn.h"

#define anz_spieler_in_dlg 2

/* Konstanten fr das Tasten-Array */
#define taste_anz 4
#define taste_links 0
#define taste_rechts 1
#define taste_dreh 2
#define taste_fall 3


/** Der Preferences-Dialog
  *@author Immi
  */

class Prefs : public QDialog  {
   Q_OBJECT
  /* Faules Programmieren... (keine get-/set-Methoden ntkig)... Nennen wir es
     extreme programming ;-) */
  friend class PrefsDaten;
public:
  Prefs(QWidget *parent=0, const char *name=0);
  ~Prefs();

protected: 
  void initDialog();
  /** Erzeugt einen von diesen Buttons, in denen
      eine Taste eingegeben wird */
  TastenBtn * erzeugTastenBtn(const char * na, int x, int y, bool text_unten);
	
  QPushButton *mOK;
  QPushButton *mAbbrechen;
  TastenBtn *mTasten[anz_spieler_in_dlg][4];
  //QCheckBox *mTaste1Spieler;
  QCheckBox *mUnfertigeLevel;
  QScrollBar *mKIGeschwindigkeit;

private: 
};

#endif
